@@ -37,7 +37,7 @@ class Logic:
         self.name=name
         self.book_path = Path(os.path.abspath((inspect.stack()[1])[1]))
         self.func_path = Path(os.path.abspath(inspect.getfile(func)))
-        self.readme_path = self.book_path.parent.joinpath(readme).resolve()
+        self.readme_path = self.book_path.parent.joinpath(readme).resolve() if self.readme != None else None
         self.func=func
         self.readme = self.get_markdown(self.readme_path) if self.readme_path != None else None
         self.tests=[]
